==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__24MainGradientMouseListener.h <==
// class javax.swing.colorchooser.DefaultHSBChooserPanel$MainGradientMouseListener

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e913c59cfad5da2b javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$update$9db91c5a2e3b2905(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$updateB$77b81b900aff46e3(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$updateH$7958bcb5312f5369(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$updateS$57ba9ea4e16044bd(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$update$9db91c5a2e3b2905;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$updateB$77b81b900aff46e3;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$updateH$7958bcb5312f5369;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$updateS$57ba9ea4e16044bd;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*update$9db91c5a2e3b2905)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
	void	(*updateB$77b81b900aff46e3)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
	void	(*updateH$7958bcb5312f5369)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
	void	(*updateS$57ba9ea4e16044bd)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__24MainGradientMouseListener.h <==
// class javax.swing.colorchooser.DefaultHSBChooserPanel$MainGradientMouseListener

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c31093a8285d3d56 javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$update$9db91c5a2e3b2905(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$updateB$77b81b900aff46e3(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$updateH$7958bcb5312f5369(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method$updateS$57ba9ea4e16044bd(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$update$9db91c5a2e3b2905;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$updateB$77b81b900aff46e3;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$updateH$7958bcb5312f5369;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$method_info$updateS$57ba9ea4e16044bd;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*update$9db91c5a2e3b2905)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
	void	(*updateB$77b81b900aff46e3)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
	void	(*updateH$7958bcb5312f5369)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
	void	(*updateS$57ba9ea4e16044bd)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24MainGradientMouseListener_H_ */
